import { defineStore } from 'pinia'
import { getResourcesPage, uploadResource, deleteResourceById } from '../../api/Resources'

export const useFilesStore = defineStore('files', {
  state: () => ({
    sharedFiles: [],
    totalPages: 1,
    currentPage: 1,
    isLoading: false,
    error: null,
  }),
  getters: {
    getFileById: (state) => (id) => {
      return state.sharedFiles.find(file => file.id === id)
    },
    isLastPage: (state) => state.currentPage === state.totalPages,
  },
  actions: {
    async fetchSharedFiles(page = 1, name = '') {
      this.isLoading = true
      this.error = null
      try {
        const response = await getResourcesPage(page, 12, name) // Assuming pageSize is 12
        this.sharedFiles = response.data.resources
        this.totalPages = response.data.totalPages
        this.currentPage = page
      } catch (error) {
        console.error('Failed to fetch shared files:', error)
        this.error = 'Failed to fetch shared files. Please try again.'
      } finally {
        this.isLoading = false
      }
    },
    async uploadFile(fileData) {
      this.isLoading = true
      this.error = null
      try {
        const response = await uploadResource(fileData)
        // Add the new file to the list if it's returned by the API
        if (response) {
          this.sharedFiles.unshift(response)
        } else {
          // If the API doesn't return the new file, refresh the whole list
          await this.fetchSharedFiles(1)
        }
      } catch (error) {
        console.error('Failed to upload file:', error)
        this.error = 'Failed to upload file. Please try again.'
      } finally {
        this.isLoading = false
      }
    },
    async deleteFile(id) {
      this.isLoading = true
      this.error = null
      try {
        await deleteResourceById(id)
        // Remove the file from the list
        this.sharedFiles = this.sharedFiles.filter(file => file.id !== id)
        // If the current page is empty and it's not the first page, fetch the previous page
        if (this.sharedFiles.length === 0 && this.currentPage > 1) {
          await this.fetchSharedFiles(this.currentPage - 1)
        }
      } catch (error) {
        console.error('Failed to delete file:', error)
        this.error = 'Failed to delete file. Please try again.'
      } finally {
        this.isLoading = false
      }
    },
  },
})